## $describe

### Target Server

$target_url

### Parameters

$params

### Request

$request

### Response

```
Status:       $status_code
Content-Type: $response_content_type
Response:
$response_body
```
